You are viewing a plain text version of this content. The canonical link for it is here.
Posted to issues@openwhisk.apache.org by GitBox <gi...@apache.org> on 2018/04/17 18:11:17 UTC

[GitHub] mhamann closed pull request #289: Use ASF strict license checking configuration for scancode.

mhamann closed pull request #289: Use ASF strict license checking configuration for scancode.
URL: https://github.com/apache/incubator-openwhisk-apigateway/pull/289
 
 
   

This is a PR merged from a forked repository.
As GitHub hides the original diff on merge, it is displayed below for
the sake of provenance:

As this is a foreign pull request (from a fork), the diff is supplied
below (as it won't show otherwise due to GitHub magic):

diff --git a/tools/build/scanCode.cfg b/tools/build/scanCode.cfg
deleted file mode 100644
index fa451e0..0000000
--- a/tools/build/scanCode.cfg
+++ /dev/null
@@ -1,43 +0,0 @@
-# scanCode.py configuration file
-
-# List of filenames containing the text of valid license (headers)
-# These files SHOULD be in the same directory path where scanCode.py
-# resides.
-[Licenses]
-ASFLicenseHeaderLua.txt
-
-# Filters (path/filename) with wildcards and associated scan checks
-# that are to be run against them.  The checks are actual valid
-# function names found in scanCode.py.
-[Includes]
-*=is_not_symlink
-*.scala=has_block_license, no_tabs, no_trailing_spaces, eol_at_eof
-*.py=no_tabs, no_trailing_spaces, eol_at_eof
-*.java=has_block_license, no_tabs, no_trailing_spaces, eol_at_eof
-*.js=no_tabs, no_trailing_spaces, eol_at_eof
-*.gradle=no_tabs, no_trailing_spaces, eol_at_eof
-*.md=no_tabs, eol_at_eof
-*.go=has_block_license, no_trailing_spaces, eol_at_eof
-*.lua=has_block_license
-build.xml=no_tabs, no_trailing_spaces, eol_at_eof
-deploy.xml=no_tabs, no_trailing_spaces, eol_at_eof
-
-# List of paths (inclusive of subdirectories) to exlude from code scanning
-[Excludes]
-# General exclusions
-.tox
-.git
-.bin
-
-# OpenWhisk APIGateway exclusions
-lua_install
-tests/lua_modules
-
-[Options]
-# Not all code files allow licenses to appear starting at the first character
-# of the file. This option tells the scan to allow licenses to appear starting
-# within first 'x' characters of each code file (as provided by this option's
-# value).
-LICENSE_SLACK_LENGTH=500
-
-[Regex]
\ No newline at end of file
diff --git a/tools/travis/build.sh b/tools/travis/build.sh
index c8d72e7..f5f91e2 100755
--- a/tools/travis/build.sh
+++ b/tools/travis/build.sh
@@ -24,10 +24,11 @@ SCRIPTDIR="$(cd "$(dirname "$0")" && pwd)"
 ROOTDIR="$SCRIPTDIR/../.."
 HOMEDIR="$ROOTDIR/.."
 WHISKDIR="$ROOTDIR/../openwhisk"
+UTILDIR="$ROOTDIR/../incubator-openwhisk-utilities"
 
-# run the scancode util. against project source code starting at its root
-cd $HOMEDIR
-incubator-openwhisk-utilities/scancode/scanCode.py $ROOTDIR --config $ROOTDIR/tools/build/scanCode.cfg
+# run scancode util. against project source using the ASF strict configuration
+cd $UTILDIR
+scancode/scanCode.py --config scancode/ASF-Release.cfg $ROOTDIR
 
 # Install OpenWhisk
 cd $WHISKDIR/ansible


 

----------------------------------------------------------------
This is an automated message from the Apache Git Service.
To respond to the message, please log on GitHub and use the
URL above to go to the specific comment.
 
For queries about this service, please contact Infrastructure at:
users@infra.apache.org


With regards,
Apache Git Services